@@ -14,6 +14,7 @@ from palp.parser import Parser
 from typing import List, Union
 from palp.network.request import Request
 from palp.network.response import Response
+from requests.cookies import RequestsCookieJar
 from palp.tool.short_module import import_module
 from palp.exception.exception_error import NotGeneratorFunctionError
 from palp.sequence.sequence_memory import FIFOSequence as FIFOSequenceMemory
@@ -136,8 +137,9 @@ class BaseSpider(Thread):
             # 先改成名字，不然后续无法序列化
             request.callback = request.callback.__name__
 
-            # 为每一个起始函数添加一个 session
+            # 为每一个起始函数添加一个 session、cookie_jar
             request.session = requests.session()
+            request.cookie_jar = RequestsCookieJar()
 
             self._queue.put(request)
 
